@@ -1,7 +1,4 @@
-"""unit tests for flake8-isort
-
-the test should pass with both isort 4 and isort 5
-"""
+"""unit tests for flake8-isort"""
 
 import collections
 import os
@@ -215,7 +212,13 @@ def test_isort_formatted_output(tmpdir):
     from sys import pid
     """
     options = collections.namedtuple(
-        'Options', ['no_isort_config', 'isort_show_traceback', 'stdin_display_name']
+        'Options',
+        [
+            'no_isort_config',
+            'isort_show_traceback',
+            'stdin_display_name',
+            'isort_no_skip_gitignore',
+        ],
     )
 
     (file_path, lines) = write_python_file(tmpdir, source)
@@ -223,7 +226,7 @@ def test_isort_formatted_output(tmpdir):
     diff = ' from __future__ import division\n+\n import os'
 
     checker = Flake8Isort(None, file_path, lines)
-    checker.parse_options(None, options(None, True, 'stdin'), None)
+    checker.parse_options(None, options(None, True, 'stdin', None), None)
     ret = list(checker.run())
     assert len(ret) == 1
     assert ret[0][0] == 3
@@ -249,3 +252,16 @@ def test_if_config_file_is_used(tmpdir, method_to_write_config):
     checker = Flake8Isort(None, file_path, lines)
     ret = list(checker.run())
     check_isort(ret, [(3, 0, 'I003 ')])
+
+
+def test_flake8(tmpdir):
+    from flake8.main import cli
+    import sys
+
+    (file_path, lines) = write_python_file(tmpdir, 'from sys import pid, path')
+
+    sys.argv = sys.argv[:2]
+    try:
+        assert isinstance(cli.main(), int)
+    except SystemExit:
+        pass
